clear all

%% import data

path = 'Data_public\DropletInEquilibrium';

% 1/h=40
datapath = strcat(path, '\SD_study_mesh40_KineticEnergy.txt');
import = importdata(datapath);
data = import.data;
dat1 = zeros(length(data), 4);
dat1(:,1:2) = data; 

datapath = strcat(path, '\SD_study_mesh40_KineticDissipationBulk.txt');
import = importdata(datapath);
data = import.data;
dat1(:,3) = data(:,2); 

datapath = strcat(path, '\SD_study_mesh40_SurfaceDivergence.txt');
import = importdata(datapath);
data = import.data;
dat1(:,4) = data(:,2); 


% 1/h=60
datapath = strcat(path, '\SD_study_mesh60_KineticEnergy.txt');
import = importdata(datapath);
data = import.data;
dat2 = zeros(length(data), 4);
dat2(:,1:2) = data; 

datapath = strcat(path, '\SD_study_mesh60_KineticDissipationBulk.txt');
import = importdata(datapath);
data = import.data;
dat2(:,3) = data(:,2); 

datapath = strcat(path, '\SD_study_mesh60_SurfaceDivergence.txt');
import = importdata(datapath);
data = import.data;
dat2(:,4) = data(:,2); 


% 1/h=80
datapath = strcat(path, '\SD_study_mesh80_KineticEnergy.txt');
import = importdata(datapath);
data = import.data;
dat3 = zeros(length(data), 4);
dat3(:,1:2) = data; 

datapath = strcat(path, '\SD_study_mesh80_KineticDissipationBulk.txt');
import = importdata(datapath);
data = import.data;
dat3(:,3) = data(:,2); 

datapath = strcat(path, '\SD_study_mesh80_SurfaceDivergence.txt');
import = importdata(datapath);
data = import.data;
dat3(:,4) = data(:,2); 


%% plot

size_label = 18;
size_tick = 14;
size_marker = 8;

% kinetic energy 
figure
set(gcf,'DefaultAxesColorOrder',[0.0 0.0 0.0])
plot(dat1(:,1), dat1(:,2), '-.', dat2(:,1), dat2(:,2), '--', dat3(:,1), dat3(:,2), '-','Linewidth', 1.2, 'MarkerSize', size_marker)
legend({'$1/h=40$', '$1/h=60$', '$1/h=80$'}, 'Interpreter', 'latex', 'FontSize', size_label, 'Location', 'northeast')
xlabel('Time', 'Interpreter', 'latex', 'FontSize', size_label)
xlim([0, 25])
set(gca, 'Fontsize', size_tick)
ylabel('Kinetic bulk energy', 'Interpreter', 'latex', 'FontSize', size_label)
set(gcf, 'color', 'w')
grid on

%export_fig 'SD_study_kineticEnergy.png'


% kinetic dissipation bulk
figure
set(gcf,'DefaultAxesColorOrder',[0.0 0.0 0.0])
plot(dat1(:,1), dat1(:,3), '-.', dat2(:,1), dat2(:,3), '--', dat3(:,1), dat3(:,3), '-','Linewidth', 1.2, 'MarkerSize', size_marker)
xlabel('Time', 'Interpreter', 'latex', 'FontSize', size_label)
xlim([0, 25])
set(gca, 'Fontsize', size_tick)
ylabel('Bulk dissipation', 'Interpreter', 'latex', 'FontSize', size_label)
set(gcf, 'color', 'w')
grid on

%export_fig 'SD_study_Dissipation.png'


% surface divergence
figure
set(gcf,'DefaultAxesColorOrder',[0.0 0.0 0.0])
plot(dat1(:,1), dat1(:,4), '-.', dat2(:,1), dat2(:,4), '--', dat3(:,1), dat3(:,4), '-','Linewidth', 1.2, 'MarkerSize', size_marker)
xlabel('Time', 'Interpreter', 'latex', 'FontSize', size_label)
xlim([0, 125])
set(gca, 'Fontsize', size_tick)
ylabel('Surface divergence', 'Interpreter', 'latex', 'FontSize', size_label)
set(gcf, 'color', 'w')
grid on

%export_fig 'SD_study_SurfaceDivergence.png'

