clear all

%% import data

path = 'Data_public\OscillatingDroplet';

% 1/h=10
datapath = strcat(path, '\OD_study_mesh10_semiAxisX.txt');
import = importdata(datapath);
dat0 = import.data;

% 1/h=20
datapath = strcat(path, '\OD_study_mesh20_semiAxisX.txt');
import = importdata(datapath);
dat1 = import.data;

% 1/h=40
datapath = strcat(path, '\OD_study_mesh40_semiAxisX.txt');
import = importdata(datapath);
dat2 = import.data;

% 1/h=60
datapath = strcat(path, '\OD_study_mesh60_semiAxisX.txt');
import = importdata(datapath);
dat3 = import.data;

% 1/h=80
datapath = strcat(path, '\OD_study_mesh80_semiAxisX.txt');
import = importdata(datapath);
dat4 = import.data;

datapath = strcat(path, '\OD_study_mesh80_KineticEnergy.txt');
import = importdata(datapath);
dat4kinE = import.data;

datapath = strcat(path, '\OD_study_mesh80_SurfaceEnergy.txt');
import = importdata(datapath);
dat4surfE = import.data;


%% plot

size_label = 18;
size_tick = 14;
size_marker = 8;

% semi-Axis
figure
set(gcf,'DefaultAxesColorOrder',[0.6 0.6 0.6; 0.0 0.0 0.0; 0.0 0.0 0.0; 0.0 0.0 0.0; 0.0 0.0 0.0])
plot(dat0(:,1), dat0(:,2), '-', dat1(:,1), dat1(:,2), ':', dat2(:,1), dat2(:,2), '-.', dat3(:,1), dat3(:,2), '--', dat4(:,1), dat4(:,2), '-','Linewidth', 1.2, 'MarkerSize', size_marker)
legend({'$1/h=10$', '$1/h=20$', '$1/h=40$', '$1/h=60$', '$1/h=80$'}, 'Interpreter', 'latex', 'FontSize', size_label, 'Location', 'northeast')
xlabel('Time', 'Interpreter', 'latex', 'FontSize', size_label)
set(gca, 'Fontsize', size_tick)
ylabel('Semi-Axis', 'Interpreter', 'latex', 'FontSize', size_label)
set(gcf, 'color', 'w')
grid on

%export_fig 'OD_study_semiAxisX.png'


% semi-Axis - close Up
figure
set(gcf,'DefaultAxesColorOrder',[0.0 0.0 0.0])
plot(dat1(:,1), dat1(:,2), ':', dat2(:,1), dat2(:,2), '-.', dat3(:,1), dat3(:,2), '--', dat4(:,1), dat4(:,2), '-','Linewidth', 1.2, 'MarkerSize', size_marker)
%legend({'$\frac{1}{h}=20$', '$\frac{1}{h}=40$', '$\frac{1}{h}=60$', '$\frac{1}{h}=80$'}, 'Interpreter', 'latex', 'FontSize', 18, 'Location', 'northeast')
xlabel('Time', 'Interpreter', 'latex', 'FontSize', size_label)
xlim([800, 1000])
set(gca, 'Fontsize', size_tick)
ax = gca;
ax.YAxis.Exponent = -1;
ylabel('Semi-axis', 'Interpreter', 'latex', 'FontSize', size_label)
ylim([0.4997, 0.5003])
set(gca, 'YTick', [0.4997 0.4999 0.5001 0.5003])
set(gcf, 'color', 'w')
grid on

%export_fig 'OD_study_semiAxisX_cU.png'


% energies
figure
set(gcf,'DefaultAxesColorOrder',[0.0 0.0 0.0])
plot(dat4kinE(:,1), dat4kinE(:,2), '-', dat4surfE(:,1), dat4surfE(:,2)-0.157118, '-.','Linewidth', 1.2, 'MarkerSize', size_marker)
legend({'Kinetic energy', 'Surface energy'}, 'Interpreter', 'latex', 'FontSize', size_label, 'Location', 'northeast')
xlabel('Time', 'Interpreter', 'latex', 'FontSize', size_label)
set(gca, 'Fontsize', size_tick)
ylabel('Energy', 'Interpreter', 'latex', 'FontSize', size_label)
set(gcf, 'color', 'w')
grid on

%export_fig 'OD_study_energies.png'
