clear all

%% import data

path = 'Data_public\RisingBubble';

% tc1 - k=2
datapath = strcat(path, '\convStudy_tc1_k2\RB_convStudy_tc1_k2_mesh4_centerOfMass.txt');
import = importdata(datapath);
data = import.data;
data1k2 = zeros(length(data), 4);
data1k2(:,1:2) = data; 

datapath = strcat(path, '\convStudy_tc1_k2\RB_convStudy_tc1_k2_mesh4_riseVelocity.txt');
import = importdata(datapath);
data = import.data;
data1k2(:,3) = data(:,2); 

datapath = strcat(path, '\convStudy_tc1_k2\RB_convStudy_tc1_k2_mesh4_circularity.txt');
import = importdata(datapath);
data = import.data;
data1k2(:,4) = data(:,2); 


% tc1 - k=3
datapath = strcat(path, '\convStudy_tc1_k3\RB_convStudy_tc1_k3_mesh3_centerOfMass.txt');
import = importdata(datapath);
data = import.data;
data1k3 = zeros(length(data), 4);
data1k3(:,1:2) = data; 

datapath = strcat(path, '\convStudy_tc1_k3\RB_convStudy_tc1_k3_mesh3_riseVelocity.txt');
import = importdata(datapath);
data = import.data;
data1k3(:,3) = data(:,2); 

datapath = strcat(path, '\convStudy_tc1_k3\RB_convStudy_tc1_k3_mesh3_circularity.txt');
import = importdata(datapath);
data = import.data;
data1k3(:,4) = data(:,2); 


%% import ref data

path = 'refData_Featflow\bench_quantities'; 
% available online at http://www.featflow.de/en/benchmarks/cfdbenchmarking/bubble/bubble_reference.html

% ref tc1
datapath = strcat(path, '\c1g1l7.txt');
c1g1 = importdata(datapath);

datapath = strcat(path, '\c1g2l3.txt');
c1g2 = importdata(datapath);

datapath = strcat(path, '\c1g3l4.txt');
c1g3 = importdata(datapath);


%% plot %%

size_label = 18;
size_tick = 14;
size_marker = 8;


%% tc1 - overall

% center of mass
figure
set(gcf,'DefaultAxesColorOrder',[0.0 0.0 0.0])
plot(c1g1(:,1), c1g1(:,4), '--', c1g2(:,1), c1g2(:,4), '--', c1g3(:,1), c1g3(:,4), '--', data1k2(:,1), data1k2(:,2), '-', data1k3(:,1), data1k3(:,2), '-', c1g1(1:2500:end,1), c1g1(1:2500:end,4), 's', c1g2(1:150:end,1), c1g2(1:150:end,4), 'o', c1g3(1:350:end,1), c1g3(1:350:end,4), '^', data1k2(1:120:end,1), data1k2(1:120:end,2), 'x', data1k3(1:130:end,1), data1k3(1:130:end,2), '+', 'Linewidth', 1.2, 'MarkerSize', size_marker)
xlabel('Time', 'Interpreter', 'latex', 'FontSize', size_label)
xlim([0, 3])
set(gca, 'XTick', [0 1 2 3], 'XTickLabel', {'0', '1', '2', '3'}, 'Fontsize', size_tick)
ylabel('Center of mass', 'Interpreter', 'latex', 'FontSize', size_label)
set(gca, 'YTick', [0.4 0.6 0.8 1.0 1.2], 'YTickLabel', {'0.4', '0.6', '0.8', '1.0', '1.2'})
set(gcf, 'color', 'w')
grid on

%export_fig 'RB_tc1_centerOfMass.png'


% rise velocity
figure
set(gcf,'DefaultAxesColorOrder',[0.0 0.0 0.0])
plot(c1g1(:,1), c1g1(:,5), '--', c1g2(:,1), c1g2(:,5), '--', c1g3(:,1), c1g3(:,5), '--', data1k2(:,1), data1k2(:,3), '-', data1k3(:,1), data1k3(:,3), '-', c1g1(1:2500:end,1), c1g1(1:2500:end,5), 's', c1g2(1:150:end,1), c1g2(1:150:end,5), 'o', c1g3(1:350:end,1), c1g3(1:350:end,5), '^', data1k2(1:120:end,1), data1k2(1:120:end,3), 'x', data1k3(1:130:end,1), data1k3(1:130:end,3), '+', 'Linewidth', 1.2, 'MarkerSize', size_marker)
[legh,objh] = legend({'TP2D','FreeLIFE','MooNMD','BoSSS (k=2)', 'BoSSS (k=3)'}, 'Interpreter', 'latex', 'FontSize', size_label, 'Location', 'southeast');
lineh = findobj(objh,'type','line')
set(lineh(2),'Marker','s')
set(lineh(4),'Marker','o')
set(lineh(6),'Marker','^')
set(lineh(8),'Marker','x')
set(lineh(10),'Marker','+')

xlabel('Time', 'Interpreter', 'latex', 'FontSize', size_label)
xlim([0, 3])
set(gca, 'XTick', [0 1 2 3], 'XTickLabel', {'0', '1', '2', '3'}, 'Fontsize', size_tick)
ylabel('Rise velocity', 'Interpreter', 'latex', 'FontSize', size_label)
ylim([0, 0.25])
set(gcf, 'color', 'w')
grid on

%export_fig 'RB_tc1_riseVelocity.png'


% circularity
figure
set(gcf,'DefaultAxesColorOrder',[0.0 0.0 0.0])
plot(c1g1(:,1), c1g1(:,3), '--', c1g2(:,1), c1g2(:,3), '--', c1g3(:,1), c1g3(:,3), '--', data1k2(:,1), data1k2(:,4), '-', data1k3(:,1), data1k3(:,4), '-', c1g1(1:2500:end,1), c1g1(1:2500:end,3), 's', c1g2(1:150:end,1), c1g2(1:150:end,3), 'o', c1g3(1:350:end,1), c1g3(1:350:end,3), '^', data1k2(1:120:end,1), data1k2(1:120:end,4), 'x', data1k3(1:130:end,1), data1k3(1:130:end,4), '+', 'Linewidth', 1.2, 'MarkerSize', size_marker)
xlabel('Time', 'Interpreter', 'latex', 'FontSize', size_label)
xlim([0, 3])
set(gca, 'XTick', [0 1 2 3], 'XTickLabel', {'0', '1', '2', '3'}, 'Fontsize', size_tick)
ylabel('Circularity', 'Interpreter', 'latex', 'FontSize', size_label)
set(gcf, 'color', 'w')
grid on

%export_fig 'RB_tc1_circularity.png'


%% tc1 - closeUp

% center of mass
figure
set(gcf,'DefaultAxesColorOrder',[0.0 0.0 0.0])
plot(c1g1(:,1), c1g1(:,4), '--', c1g2(:,1), c1g2(:,4), '--', c1g3(:,1), c1g3(:,4), '--', data1k2(:,1), data1k2(:,2), '-', data1k3(:,1), data1k3(:,2), '-', c1g1(1:400:end,1), c1g1(1:400:end,4), 's', c1g2(1:20:end,1), c1g2(1:20:end,4), 'o', c1g3(1:50:end,1), c1g3(1:50:end,4), '^', data1k2(1:20:end,1), data1k2(1:20:end,2), 'x', data1k3(1:30:end,1), data1k3(1:30:end,2), '+', 'Linewidth', 1.2, 'MarkerSize', size_marker)
xlabel('Time', 'Interpreter', 'latex', 'FontSize', size_label)
xlim([2.7, 3])
set(gca, 'Fontsize', size_tick)
set(gca, 'XTick', [2.7 2.8 2.9 3], 'XTickLabel', {'2.7', '2.8', '2.9', '3'})
ylabel('Center of mass', 'Interpreter', 'latex', 'FontSize', size_label)
set(gca, 'YTick', [1.03 1.05 1.07 1.09], 'YTickLabel', {'1.03', '1.05', '1.07', '1.09'})
set(gcf, 'color', 'w')
grid on

%export_fig 'RB_tc1_centerOfMass_cU.png'


% rise velocity
figure
set(gcf,'DefaultAxesColorOrder',[0.0 0.0 0.0])
plot(c1g1(:,1), c1g1(:,5), '--', c1g2(:,1), c1g2(:,5), '--', c1g3(:,1), c1g3(:,5), '--', data1k2(:,1), data1k2(:,3), '-', data1k3(:,1), data1k3(:,3), '-', c1g1(1:400:end,1), c1g1(1:400:end,5), 's', c1g2(1:20:end,1), c1g2(1:20:end,5), 'o', c1g3(1:50:end,1), c1g3(1:50:end,5), '^', data1k2(1:20:end,1), data1k2(1:20:end,3), 'x', data1k3(1:30:end,1), data1k3(1:30:end,3), '+', 'Linewidth', 1.2, 'MarkerSize', size_marker)
xlabel('Time', 'Interpreter', 'latex', 'FontSize', size_label)
xlim([0.8, 1.1])
set(gca, 'Fontsize', size_tick)
set(gca, 'XTick', [0.8 0.9 1.0 1.1], 'XTickLabel', {'0.8', '0.9', '1.0', '1.1'})
ylabel('Rise velocity', 'Interpreter', 'latex', 'FontSize', size_label)
ylim([0.237, 0.243])
set(gca, 'YTick', [0.237 0.239 0.241 0.243], 'YTickLabel', {'0.237', '0.239', '0.241', '0.243'})
set(gcf, 'color', 'w')
grid on

%export_fig 'RB_tc1_riseVelocity_cU.png'


% circularity
figure
set(gcf,'DefaultAxesColorOrder',[0.0 0.0 0.0])
plot(c1g1(:,1), c1g1(:,3), '--', c1g2(:,1), c1g2(:,3), '--', c1g3(:,1), c1g3(:,3), '--', data1k2(:,1), data1k2(:,4), '-', data1k3(:,1), data1k3(:,4), '-', c1g1(1:400:end,1), c1g1(1:400:end,3), 's', c1g2(1:20:end,1), c1g2(1:20:end,3), 'o', c1g3(1:50:end,1), c1g3(1:50:end,3), '^', data1k2(1:20:end,1), data1k2(1:20:end,4), 'x', data1k3(1:30:end,1), data1k3(1:30:end,4), '+', 'Linewidth', 1.2, 'MarkerSize', size_marker)
xlabel('Time', 'Interpreter', 'latex', 'FontSize', size_label)
xlim([1.8, 2])
set(gca, 'Fontsize', size_tick)
ylabel('Circularity', 'Interpreter', 'latex', 'FontSize', size_label)
set(gca, 'YTick', [0.901 0.902 0.903], 'YTickLabel', {'0.901', '0.902', '0.903'})
set(gcf, 'color', 'w')
grid on

%export_fig 'RB_tc1_circularity_cU.png'




