clear all

%% import data

path = 'Data_public\RisingBubble';

% tc2 - k=2
datapath = strcat(path, '\convStudy_tc2_k2\RB_convStudy_tc2_k2_mesh3_centerOfMass.txt');
import = importdata(datapath);
data = import.data;
data2k2 = zeros(length(data), 4);
data2k2(:,1:2) = data; 

datapath = strcat(path, '\convStudy_tc2_k2\RB_convStudy_tc2_k2_mesh3_riseVelocity.txt');
import = importdata(datapath);
data = import.data;
data2k2(:,3) = data(:,2); 

datapath = strcat(path, '\convStudy_tc2_k2\RB_convStudy_tc2_k2_mesh3_circularity.txt');
import = importdata(datapath);
data = import.data;
data2k2(:,4) = data(:,2); 


%% import ref data

path = 'refData_Featflow\bench_quantities';
% available online at http://www.featflow.de/en/benchmarks/cfdbenchmarking/bubble/bubble_reference.html

% ref tc2
datapath = strcat(path, '\c2g1l8.txt');
c2g1 = importdata(datapath);

datapath = strcat(path, '\c2g2l3.txt');
c2g2 = importdata(datapath);

datapath = strcat(path, '\c2g3l4.txt');
c2g3 = importdata(datapath);


%% plot %%

size_label = 18;
size_tick = 14;
size_marker = 8;


%% tc2 - overall

% center of mass
figure
set(gcf,'DefaultAxesColorOrder',[0.0 0.0 0.0])
plot(c2g1(:,1), c2g1(:,4), '--', c2g2(:,1), c2g2(:,4), '--', c2g3(:,1), c2g3(:,4), '--', data2k2(:,1), data2k2(:,2), '-', c2g1(1:2500:end,1), c2g1(1:2500:end,4), 's', c2g2(1:150:end,1), c2g2(1:150:end,4), 'o', c2g3(1:350:end,1), c2g3(1:350:end,4), '^', data2k2(1:120:end,1), data2k2(1:120:end,2), 'x', 'Linewidth', 1.2, 'MarkerSize', size_marker)
xlabel('Time', 'Interpreter', 'latex', 'FontSize', 18)
xlim([0, 3])
set(gca, 'XTick', [0 1 2 3], 'XTickLabel', {'0', '1', '2', '3'}, 'Fontsize', size_tick)
ylabel('Center of mass', 'Interpreter', 'latex', 'FontSize', size_label)
set(gca, 'YTick', [0.4 0.6 0.8 1.0 1.2], 'YTickLabel', {'0.4', '0.6', '0.8', '1.0', '1.2'})
set(gcf, 'color', 'w')
grid on

%export_fig 'RB_tc2_centerOfMass.png'


% rise velocity
figure
set(gcf,'DefaultAxesColorOrder',[0.0 0.0 0.0])
plot(c2g1(:,1), c2g1(:,5), '--', c2g2(:,1), c2g2(:,5), '--', c2g3(:,1), c2g3(:,5), '--', data2k2(:,1), data2k2(:,3), '-', c2g1(1:2500:end,1), c2g1(1:2500:end,5), 's', c2g2(1:150:end,1), c2g2(1:150:end,5), 'o', c2g3(1:350:end,1), c2g3(1:350:end,5), '^', data2k2(1:120:end,1), data2k2(1:120:end,3), 'x', 'Linewidth', 1.2, 'MarkerSize', size_marker)
[legh,objh] = legend({'TP2D','FreeLIFE','MooNMD','BoSSS'}, 'Interpreter', 'latex', 'FontSize', size_label, 'Location', 'southeast');
lineh = findobj(objh,'type','line')
set(lineh(2),'Marker','s')
set(lineh(4),'Marker','o')
set(lineh(6),'Marker','^')
set(lineh(8),'Marker','x')

xlabel('Time', 'Interpreter', 'latex', 'FontSize', 18)
xlim([0, 3])
set(gca, 'XTick', [0 1 2 3], 'XTickLabel', {'0', '1', '2', '3'}, 'Fontsize', size_tick)
ylabel('Rise velocity', 'Interpreter', 'latex', 'FontSize', size_label)
ylim([0, 0.3])
set(gca, 'YTick', [0 0.1 0.2 0.3], 'YTickLabel', {'0', '0.1', '0.2', '0.3'})
set(gcf, 'color', 'w')
grid on

%export_fig 'RB_tc2_riseVelocity.png'


% circularity
figure
set(gcf,'DefaultAxesColorOrder',[0.0 0.0 0.0])
plot(c2g1(:,1), c2g1(:,3), '--', c2g2(:,1), c2g2(:,3), '--', c2g3(:,1), c2g3(:,3), '--', data2k2(:,1), data2k2(:,4), '-', c2g1(1:2500:end,1), c2g1(1:2500:end,3), 's', c2g2(1:150:end,1), c2g2(1:150:end,3), 'o', c2g3(1:350:end,1), c2g3(1:350:end,3), '^', data2k2(1:120:end,1), data2k2(1:120:end,4), 'x', 'Linewidth', 1.2, 'MarkerSize', size_marker)
xlabel('Time', 'Interpreter', 'latex', 'FontSize', size_label)
xlim([0, 3])
set(gca, 'XTick', [0 1 2 3], 'XTickLabel', {'0', '1', '2', '3'}, 'Fontsize', size_tick)
ylabel('Circularity', 'Interpreter', 'latex', 'FontSize', size_label)
set(gca, 'YTick', [0.4 0.6 0.8 1.0], 'YTickLabel', {'0.4', '0.6', '0.8', '1.0'})
set(gcf, 'color', 'w')
grid on

%export_fig 'RB_tc2_circularity.png'


%% tc2 - closeUp

% center of mass
figure
set(gcf,'DefaultAxesColorOrder',[0.0 0.0 0.0])
plot(c2g1(:,1), c2g1(:,4), '--', c2g2(:,1), c2g2(:,4), '--', c2g3(:,1), c2g3(:,4), '--', data2k2(:,1), data2k2(:,2), '-', c2g1(1:1800:end,1), c2g1(1:1800:end,4), 's', c2g2(1:80:end,1), c2g2(1:80:end,4), 'o', c2g3(1:30:end,1), c2g3(1:30:end,4), '^', data2k2(1:60:end,1), data2k2(1:60:end,2), 'x', 'Linewidth', 1.2, 'MarkerSize', size_marker)
xlabel('Time', 'Interpreter', 'latex', 'FontSize', size_label)
xlim([2, 3])
set(gca, 'Fontsize', size_tick)
ylabel('Center of mass', 'Interpreter', 'latex', 'FontSize', size_label)
set(gcf, 'color', 'w')
grid on

%export_fig 'RB_tc2_centerOfMass_cU.png'


% rise velocity
figure
set(gcf,'DefaultAxesColorOrder',[0.0 0.0 0.0])
plot(c2g1(:,1), c2g1(:,5), '--', c2g2(:,1), c2g2(:,5), '--', c2g3(:,1), c2g3(:,5), '--', data2k2(:,1), data2k2(:,3), '-', c2g1(1:1800:end,1), c2g1(1:1800:end,5), 's', c2g2(1:80:end,1), c2g2(1:80:end,5), 'o', c2g3(1:30:end,1), c2g3(1:30:end,5), '^', data2k2(1:60:end,1), data2k2(1:60:end,3), 'x', 'Linewidth', 1.2, 'MarkerSize', size_marker)
xlabel('Time', 'Interpreter', 'latex', 'FontSize', size_label)
xlim([0.5, 2.2])
set(gca, 'Fontsize', size_tick)
ylabel('Rise velocity', 'Interpreter', 'latex', 'FontSize', size_label)
ylim([0.2, 0.26])
set(gca, 'YTick', [0.2 0.22 0.24 0.26], 'YTickLabel', {'0.2', '0.22', '0.24', '0.26'})
set(gcf, 'color', 'w')
grid on

%export_fig 'RB_tc2_riseVelocity_cU.png'


% circularity
figure
set(gcf,'DefaultAxesColorOrder',[0.0 0.0 0.0])
plot(c2g1(:,1), c2g1(:,3), '--', c2g2(:,1), c2g2(:,3), '--', c2g3(:,1), c2g3(:,3), '--', data2k2(:,1), data2k2(:,4), '-', c2g1(1:1800:end,1), c2g1(1:1800:end,3), 's', c2g2(1:80:end,1), c2g2(1:80:end,3), 'o', c2g3(1:30:end,1), c2g3(1:30:end,3), '^', data2k2(1:60:end,1), data2k2(1:60:end,4), 'x', 'Linewidth', 1.2, 'MarkerSize', size_marker)
xlabel('Time', 'Interpreter', 'latex', 'FontSize', size_label)
xlim([1.5, 3])
set(gca, 'Fontsize', size_tick)
ylabel('Circularity', 'Interpreter', 'latex', 'FontSize', size_label)
set(gca, 'YTick', [0.5 0.6 0.7 0.8], 'YTickLabel', {'0.5', '0.6', '0.7', '0.8'})
set(gcf, 'color', 'w')
grid on

%export_fig 'RB_tc2_circularity_cU.png'
